@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +30,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 #ifndef YY_YY_CFG_PARSE_H_INCLUDED
 # define YY_YY_CFG_PARSE_H_INCLUDED
 /* Debug traces.  */
@@ -80,12 +83,12 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 65 "cfg_parse.y" /* yacc.c:1909  */
+#line 65 "cfg_parse.y" /* yacc.c:1906  */
 
 	int value;
 	char *string;
 
-#line 89 "cfg_parse.h" /* yacc.c:1909  */
+#line 92 "cfg_parse.h" /* yacc.c:1906  */
 };
 
 typedef union YYSTYPE YYSTYPE;
